@@ -34,8 +34,7 @@ CONFIGURATION_FILE_PATH = get_existent_path(
 )
 
 DEFAULT_CONFIG = {
-    "session_file": "cli_session_animdl.json",
-    "default_provider": "zoro",
+    "default_provider": "animixplay",
     "site_urls": {
         "9anime": "https://9anime.to/",
         "allanime": "https://allanime.site/",
@@ -142,7 +141,6 @@ ANICHART = CONFIG.get("schedule", {}).get("site_url")
 DATE_FORMAT = CONFIG.get("schedule", {}).get("date_format")
 TIME_FORMAT = CONFIG.get("schedule", {}).get("time_format")
 
-SESSION_FILE = CONFIG.get("session_file")
 DEFAULT_PROVIDER = CONFIG.get("default_provider")
 
 AUTO_RETRY = CONFIG.get("download_auto_retry", 300) / 1000
